@@ -1,4 +1,5 @@
 {-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 {-# OPTIONS_GHC -fspec-constr -fspec-constr-count=8 #-}
 {-# LANGUAGE CPP #-}
@@ -99,6 +100,7 @@ import Data.String
 import Data.Text hiding (empty,zip,foldl,foldl')
 import qualified Text.ParserCombinators.ReadP as ReadP
 import qualified Text.Parsec as Parsec
+import qualified Data.Attoparsec.Types as Att
 import Text.Parser.Char
 import Text.Parser.Combinators
 import Text.Parser.Token.Highlight
@@ -681,6 +683,9 @@ instance Parsing m => Parsing (Unhighlighted m) where
   {-# INLINE unexpected #-}
   eof = Unhighlighted eof
   {-# INLINE eof #-}
+  notFollowedBy (Unhighlighted m) = Unhighlighted $ notFollowedBy m
+  {-# INLINE notFollowedBy #-}
+
 
 instance MonadTrans Unhighlighted where
   lift = Unhighlighted
@@ -710,6 +715,8 @@ instance Parsing m => Parsing (Unspaced m) where
   {-# INLINE unexpected #-}
   eof = Unspaced eof
   {-# INLINE eof #-}
+  notFollowedBy (Unspaced m) = Unspaced $ notFollowedBy m
+  {-# INLINE notFollowedBy #-}
 
 instance MonadTrans Unspaced where
   lift = Unspaced
@@ -739,6 +746,8 @@ instance Parsing m => Parsing (Unlined m) where
   {-# INLINE unexpected #-}
   eof = Unlined eof
   {-# INLINE eof #-}
+  notFollowedBy (Unlined m) = Unlined $ notFollowedBy m
+  {-# INLINE notFollowedBy #-}
 
 instance MonadTrans Unlined where
   lift = Unlined
@@ -756,4 +765,6 @@ instance TokenParsing m => TokenParsing (Unlined m) where
 
 instance Parsec.Stream s m Char => TokenParsing (Parsec.ParsecT s u m)
 
+instance Att.Chunk t => TokenParsing (Att.Parser t)
+
 instance TokenParsing ReadP.ReadP
